#
# spec file for package yate
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
# Copyright (c) 2011, Sascha Peilicke <saschpe@gmx.de>
# Copyright (c) 2011, Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           yate
Version:        4.1.0
Release:        34.1
Summary:        Yet Another Telephony Engine
License:        GPL-2.0+
Group:          Productivity/Telephony/Clients
Url:            http://www.yate.null.ro/
Source0:        http://yate.null.ro/tarballs/yate4/yate-%{version}-1.tar.gz
Patch1:         yate-3.3.2-ppc64-libdir.patch
Patch2:         yate-ppc64.patch
Patch3:         dont-mess-with-cflags.patch
Patch4:         yate-fix-ssl-detection.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  autoconf
BuildRequires:  gcc-c++
BuildRequires:  libqt4-devel
%if 0%{?fedora_version} || 0%{?rhel_version} || 0%{?centos_version}
BuildRequires:  openssl-devel
%else
BuildRequires:  libopenssl-devel
BuildRequires:  pwlib-devel
BuildRequires:  speex-devel
%if 0%{?suse_version} >= 1110
BuildRequires:  alsa-devel
BuildRequires:  update-desktop-files
%if 0%{?sles_version}
%else
BuildRequires:  libgsm-devel
BuildRequires:  openh323-devel
%if 0%{?suse_version} <= 1210
BuildRequires:  spandsp-devel
%endif
%endif
%endif
%endif
%if 0%{?packman_bs}
BuildRequires:  libamrnb-devel
%endif

%description
Yate is a next-generation telephony engine. While currently focused on Voice
over Internet Protocol (VoIP) and PSTN, its power lies in its ability to be
easily extended. Voice, video, data and instant messenging can all be unified
under Yate's flexible routing engine, maximizing communications efficiency and
minimizing infrastructure costs for businesses.

%package devel
Summary:        Development package for Yate
License:        GPL-2.0
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
This package contains all necessary include files and libraries needed
to compile and develop applications that use Yate.

%package qt4
Summary:        Qt-4 client package for Yate
License:        GPL-2.0
Group:          Productivity/Telephony/Clients
Requires:       %{name} = %{version}

%description qt4
The yate-qt4 package includes the files needed to use Yate as a VoIP client
with a Qt4 graphical interface.

%package scripts
Summary:        External scripting package for Yate
License:        GPL-2.0
Group:          Productivity/Telephony/Clients
Requires:       %{name}
Requires:       php5

%description scripts
The yate-scripts package includes libraries for using external scripts with Yate.

%if 0%{?packman_bs}

%package with-amrnb
Summary:        Yate with amrnb codec support
License:        GPL-2.0
Group:          Productivity/Telephony/Clients
Requires:       %{name} = %{version}-%{release}

%description with-amrnb
Guarantees Yate with amrnb codec support.
%endif

%prep
%setup -q -n %{name}
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4

%build
rm configure
autoconf

%configure --docdir=%{_docdir}
make #%{?_smp_mflags} # Parallel build causes side-effects (compile errors)

%install
%makeinstall
%suse_update_desktop_file -i %{name}-qt4 Network Telephony Qt
rm %{buildroot}/usr/lib/menu/yate-qt4.menu # Unused, causes lots of rpmlint warnings
mkdir -p %{buildroot}%{_docdir}/%{name} # We want docs in /usr/share/doc/packages/yate
mv %{buildroot}%{_datadir}/doc/%{name}-%{version} %{buildroot}%{_docdir}/%{name}

%if 0%{?packman_bs}
cat<<EOF >README.amrnb
This %{name} package has been built with amrnb support.
EOF
%endif

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%post qt4 -p /sbin/ldconfig

%postun qt4 -p /sbin/ldconfig

%files
%defattr (-,root,root)
%doc ChangeLog COPYING README
%{_bindir}/%{name}
%{_mandir}/man*/%{name}.*
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/data
%{_libdir}/lib%{name}.so.*
%{_libdir}/libyatejabber.so.*
%{_libdir}/libyatesig.so.*
%{_libdir}/libyatemgcp.so.*
%{_libdir}/libyatescript.so.*
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/analyzer.yate
%{_libdir}/%{name}/callfork.yate
%{_libdir}/%{name}/callgen.yate
%{_libdir}/%{name}/cdrbuild.yate
%{_libdir}/%{name}/cdrfile.yate
%{_libdir}/%{name}/client
%{_libdir}/%{name}/conference.yate
%{_libdir}/%{name}/dumbchan.yate
%{_libdir}/%{name}/enumroute.yate
%{_libdir}/%{name}/extmodule.yate
%{_libdir}/%{name}/filetransfer.yate
%if 0%{?suse_version} && 0%{?suse_version} <= 1210 && ! 0%{?sles_version}
%{_libdir}/%{name}/faxchan.yate
%endif
%{_libdir}/%{name}/gvoice.yate
%if 0%{?suse_version} && ! 0%{?sles_version}
%{_libdir}/%{name}/gsmcodec.yate
%{_libdir}/%{name}/h323chan.yate
%endif
%{_libdir}/%{name}/ilbccodec.yate
%{_libdir}/%{name}/isaccodec.yate
%{_libdir}/%{name}/jabber
%{_libdir}/%{name}/javascript.yate
%{_libdir}/%{name}/moh.yate
%{_libdir}/%{name}/msgsniff.yate
%{_libdir}/%{name}/mux.yate
%{_libdir}/%{name}/openssl.yate
%{_libdir}/%{name}/pbx.yate
%{_libdir}/%{name}/regexroute.yate
%{_libdir}/%{name}/rmanager.yate
%{_libdir}/%{name}/server
%{_libdir}/%{name}/sip
%{_libdir}/%{name}/speexcodec.yate
%{_libdir}/%{name}/tonedetect.yate
%{_libdir}/%{name}/tonegen.yate
%{_libdir}/%{name}/wavefile.yate
%{_libdir}/%{name}/yiaxchan.yate
%{_libdir}/%{name}/yjinglechan.yate
%{_libdir}/%{name}/yrtpchan.yate
%{_libdir}/%{name}/ysipchan.yate
%{_libdir}/%{name}/ysockschan.yate
%{_libdir}/%{name}/ystunchan.yate
%{_libdir}/%{name}/zlibcompress.yate
%if 0%{?packman_bs}
%{_libdir}/%{name}/amrnbcodec.yate
%endif
%dir %{_libdir}/%{name}/sig
%{_libdir}/%{name}/sig/camel_map.yate
%{_libdir}/%{name}/sig/isupmangler.yate
%{_libdir}/%{name}/sig/ss7_lnp_ansi.yate
%dir %config(noreplace) %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/accfile.conf
%config(noreplace) %{_sysconfdir}/%{name}/analog.conf
%config(noreplace) %{_sysconfdir}/%{name}/cache.conf
%config(noreplace) %{_sysconfdir}/%{name}/callcounters.conf
%config(noreplace) %{_sysconfdir}/%{name}/callfork.conf
%config(noreplace) %{_sysconfdir}/%{name}/camel_map.conf
%config(noreplace) %{_sysconfdir}/%{name}/ccongestion.conf
%config(noreplace) %{_sysconfdir}/%{name}/cdrbuild.conf
%config(noreplace) %{_sysconfdir}/%{name}/cdrfile.conf
%config(noreplace) %{_sysconfdir}/%{name}/ciscosm.conf
%config(noreplace) %{_sysconfdir}/%{name}/clustering.conf
%config(noreplace) %{_sysconfdir}/%{name}/cpuload.conf
%config(noreplace) %{_sysconfdir}/%{name}/dbpbx.conf
%config(noreplace) %{_sysconfdir}/%{name}/dsoundchan.conf
%config(noreplace) %{_sysconfdir}/%{name}/enumroute.conf
%config(noreplace) %{_sysconfdir}/%{name}/extmodule.conf
%config(noreplace) %{_sysconfdir}/%{name}/filetransfer.conf
%config(noreplace) %{_sysconfdir}/%{name}/gvoice.conf
%config(noreplace) %{_sysconfdir}/%{name}/h323chan.conf
%config(noreplace) %{_sysconfdir}/%{name}/heartbeat.conf
%config(noreplace) %{_sysconfdir}/%{name}/isupmangler.conf
%config(noreplace) %{_sysconfdir}/%{name}/jabberclient.conf
%config(noreplace) %{_sysconfdir}/%{name}/jabberserver.conf
%config(noreplace) %{_sysconfdir}/%{name}/javascript.conf
%config(noreplace) %{_sysconfdir}/%{name}/jbfeatures.conf
%config(noreplace) %{_sysconfdir}/%{name}/lateroute.conf
%config(noreplace) %{_sysconfdir}/%{name}/mgcpca.conf
%config(noreplace) %{_sysconfdir}/%{name}/mgcpgw.conf
%config(noreplace) %{_sysconfdir}/%{name}/moh.conf
%config(noreplace) %{_sysconfdir}/%{name}/monitoring.conf
%config(noreplace) %{_sysconfdir}/%{name}/mux.conf
%config(noreplace) %{_sysconfdir}/%{name}/mysqldb.conf
%config(noreplace) %{_sysconfdir}/%{name}/openssl.conf
%config(noreplace) %{_sysconfdir}/%{name}/pbxassist.conf
%config(noreplace) %{_sysconfdir}/%{name}/pgsqldb.conf
%config(noreplace) %{_sysconfdir}/%{name}/presence.conf
%config(noreplace) %{_sysconfdir}/%{name}/queues.conf
%config(noreplace) %{_sysconfdir}/%{name}/queuesnotify.conf
%config(noreplace) %{_sysconfdir}/%{name}/regexroute.conf
%config(noreplace) %{_sysconfdir}/%{name}/regfile.conf
%config(noreplace) %{_sysconfdir}/%{name}/register.conf
%config(noreplace) %{_sysconfdir}/%{name}/rmanager.conf
%config(noreplace) %{_sysconfdir}/%{name}/sip_cnam_lnp.conf
%config(noreplace) %{_sysconfdir}/%{name}/sigtransport.conf
%config(noreplace) %{_sysconfdir}/%{name}/sipfeatures.conf
%config(noreplace) %{_sysconfdir}/%{name}/ss7_lnp_ansi.conf
%config(noreplace) %{_sysconfdir}/%{name}/subscription.conf
%config(noreplace) %{_sysconfdir}/%{name}/tdmcard.conf
%config(noreplace) %{_sysconfdir}/%{name}/tonegen.conf
%config(noreplace) %{_sysconfdir}/%{name}/users.conf
%config(noreplace) %{_sysconfdir}/%{name}/wpcard.conf
%config(noreplace) %{_sysconfdir}/%{name}/yate.conf
%config(noreplace) %{_sysconfdir}/%{name}/yiaxchan.conf
%config(noreplace) %{_sysconfdir}/%{name}/yjinglechan.conf
%config(noreplace) %{_sysconfdir}/%{name}/yradius.conf
%config(noreplace) %{_sysconfdir}/%{name}/yrtpchan.conf
%config(noreplace) %{_sysconfdir}/%{name}/ysigchan.conf
%config(noreplace) %{_sysconfdir}/%{name}/ysipchan.conf
%config(noreplace) %{_sysconfdir}/%{name}/ysnmpagent.conf
%config(noreplace) %{_sysconfdir}/%{name}/ysockschan.conf
%config(noreplace) %{_sysconfdir}/%{name}/ystunchan.conf
%config(noreplace) %{_sysconfdir}/%{name}/zapcard.conf
%config(noreplace) %{_sysconfdir}/%{name}/zlibcompress.conf

%files devel
%defattr (-,root,root)
%{_includedir}/%{name}
%{_libdir}/lib*.so
%{_bindir}/%{name}-config
%{_mandir}/*/%{name}-config.*
%{_libdir}/pkgconfig/%{name}.pc

%files qt4
%defattr(-, root, root)
%{_bindir}/yate-qt4
%{_libdir}/libyateqt4.so.*
%{_libdir}/%{name}/qt4
%{_datadir}/applications/yate-qt4.desktop
%{_datadir}/pixmaps/null_team-*.png
%{_datadir}/%{name}/skins
%{_datadir}/%{name}/sounds
%{_datadir}/%{name}/help
%config(noreplace) %{_sysconfdir}/%{name}/yate-qt4.conf
%config(noreplace) %{_sysconfdir}/%{name}/providers.conf

%files scripts
%defattr (-,root,root)
%{_datadir}/%{name}/scripts

%if 0%{?packman_bs}

%files with-amrnb
%defattr (-,root,root)
%doc README.amrnb
%endif

%changelog
* Mon Apr 22 2013 dimstar@opensuse.org
- Add yate-fix-ssl-detection.patch: Fix openssl detection: checkin
  for the return value of pkg-config --cflags $pkg, and relying on
  pkg-config returning an empty string 'when package exists but
  does not specify CFLAGS' is just wrong.
* Wed Mar 20 2013 idonmez@suse.com
- dont-mess-with-cflags.patch: don't mess with CFLAGS
* Tue Mar 19 2013 schwab@suse.de
- Add aarch64 to the list of lib64 platforms
* Tue Jul  3 2012 dvaleev@suse.com
- add ppc64 to the known platforms
* Wed Jun  6 2012 fisiu@opensuse.org
- Update to 4.1.0, no changelog from upstream provided.
* Wed Mar  7 2012 dvaleev@suse.com
- fix wrong libdir for ppc64.
* Thu Jan  5 2012 pascal.bleser@opensuse.org
- update to 3.3.2:
  upstream does not provide any changelog
* Thu Sep 29 2011 saschpe@suse.de
- Set license to GPL-2.0+ (SPDX style)
- The scripts sub-package now requires php5
- PHP scripts now again point to "/usr/bin/php" as the php5 package doesn't
  provide a 'php5' binary anymore
* Fri Jan 28 2011 saschpe@gmx.de
- Split of scripts package, packaged apidocs
- Added dependencies to OpenH323 and SpanDSP
- Fixed several rpmlint warnings
* Fri Jan 28 2011 saschpe@suse.de
- Fixed php scripts to not point to "/usr/bin/php" (not present
  on openSUSE)
- Added some packager comments
* Fri Jan 28 2011 saschpe@suse.de
- Better BuildRequires for non-SUSE distros
* Wed Jan 26 2011 saschpe@suse.de
- Initial version (3.0.0)
